library(rvest)
library(tidyverse)
library(dplyr)
library(stevemisc)


filenames <- c(sapply(list.files("hasznaltauto/cars/"),function(x){paste0("hasznaltauto/cars/",x)}) |> as.vector(),
							 sapply(list.files("hasznaltauto/cars2/"),function(x){paste0("hasznaltauto/cars2/",x)}) |> as.vector())

get_car <- function(x){
	if(file.info(x)$size==0){
		return(NA)
	}
	tryCatch(
		{
			data <- read_html(x)

			markaurls <- data |> html_elements("a") |> html_attr("href")
			markaurls <- markaurls[markaurls |> grep("https://www.hasznaltauto.hu/szemelyauto/",x=_) |> max()]
			markamodel <- markaurls |> str_split("/") |> unlist()
			markamodel <- markamodel |> tail(length(markamodel)-4)
			marka <- head(markamodel,1)
			modell <- tail(markamodel,1)
			# rm(markaurls,markamodel)

			data <- data |> html_element(".hirdetesadatok")
			if(is.na(data)){
				return(NA)
			}
			tab <- data |> html_table(trim = T,dec = ",",header = T)
			rovid_nev <- sapply(tab[,1], nchar) < 100 |> c()
			tab <- tab[rovid_nev,]
			dfa <- t(tab) |> as.data.frame()
			names(dfa)<-
				make.names(dfa[1,],unique = TRUE) #|> sapply( function(x){temp <- gsub(".","",x);gsub(" ","",temp)})
			dfa <- dfa[2,]
			dfa <- dfa |> select(-contains("Finanszírozás")) |> select(-contains("Garancia")) |>
				select(-contains("Átírás")) |> select(-contains("Előélet")) |> select(-contains("Motor adatok")) |>
				select(-contains("Jármű adatok")) |> select(-contains("Általános adatok"))
			names(dfa) <-
				gsub("[.]","",names(dfa), perl = F)
			rownames(dfa) <- x
			dfa$Márka <- marka
			dfa$Modell <- modell
			return(dfa)
		},
		error=function(e) {
			message('An Error Occurred')
			print(e)
			err = T
			return(NA)
		},
		warning=function(w) {
			message('A Warning Occurred')
			print(w)
			return(NA)
		}
	)
}

df <- get_car(filenames[1])
df
for(x in filenames[-1]){
	car <- get_car(x)
	print(x)
	if (sum(is.na(car))==1){
		next
	}
		df <- bind_rows(df,car)
}
write_csv(df,file = "fullszuretlen.csv")
# szűrés
# rownames(df2) <-
df2 <- df |> distinct(Vételár,VételárEUR,Évjárat,Állapot,
											Kivitel,Kmóraállás,Szállíthatószemszáma,Ajtókszáma,Szín,
											Klímafajtája,Tető,Üzemanyag,
											Teljesítmény,Hajtás,Sebességváltó, Csomagtartó,
											Műszakivizsgaérvényes,Okmányokjellege,Sajáttömeg,
											Hengerűrtartalom,Hengerelrendezés,Márka,Modell,.keep_all = F)
summary(df2)
df2 |> distinct()
df2.1 <- df2[grepl("cars/",rownames(df2)),]
df2.2 <- df2[grepl("cars2/",rownames(df2)),]
rownames(df2.1)  <- sapply(rownames(df2.1),function(x){unlist(strsplit(x,"/"))[3]})
rownames(df2.2)  <- sapply(rownames(df2.2),function(x){unlist(strsplit(x,"/"))[3]})
merge(df2.1,df2.2,all.x=T)

datafin <- merge(df2.1, df2.2[!(rownames(df2.2) %in% rownames(df2.1)),],all = T)

write.csv(datafin,file = "szurt-formazatlan.csv")
